@@ -100,10 +100,10 @@ def init_client(
         mona_host=os.environ.get('MONA_HOST') or '127.0.0.1',
         mona_port=int(os.environ.get('MONA_PORT') or 24224),
         user_id=os.environ.get('MONA_USER_ID') or 'EMPTY',
-        queue_maxsize=int(os.environ.get('MONA_QUEUE_SIZE') or 20),
+        queue_maxsize=int(os.environ.get('MONA_QUEUE_SIZE') or 200),
         queue_circular=_get_boolean_value_for_env_var('MONA_QUEUE_CIRCULAR',
-                                                      True),
-        blocking=_get_boolean_value_for_env_var('MONA_BLOCKING', False)):
+                                                      False),
+        blocking=_get_boolean_value_for_env_var('MONA_BLOCKING', True)):
     """
     Inits the client. Must be called once before starting to create contexts
     and exporting data.
